@@ -6,8 +6,9 @@ mod conditionals;
 mod config_file;
 mod filenames;
 mod git;
+mod git_instead_of;
+mod git_over_ssh;
 mod hooks_and_rhai;
-mod online;
 mod public_api;
 mod template_config_file;
 mod template_filters;
